clear;
clc;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% To run this code:
% 1. Data in: us_data_variables_used.xls
% 2. Programs: olsgmm.m
% Code output: Output_2002.xls
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%---load data up to 2002
[data_2013_gw]=xlsread('us_data_1946_2013_goyal_french_wrds',1,'a2:aw817');  

year_2013=data_2013_gw(:,1);
month_2013=data_2013_gw(:,2);

%---make sure sample is 1946.01 to 2013.12 
ind_2013=find(year_2013>=1946 & year_2013<2014);
ind_2013_init=find(year_2013>=1946 & year_2013<1980);
%---reit sample is 1972.01 to 2013.12 
ind_reit=find(year_2013>=1972 & year_2013<2014);
ind_reit_init=find(year_2013>=1972 & year_2013<1980);

%---load market returns, various proxies
vwret=data_2013_gw(ind_2013,3); %vwretd downloaded in 2014
spret=data_2013_gw(ind_2013,4); %sp500 return downloaded in 2014

%---load GW(2013) controls
tbill=data_2013_gw(ind_2013,9);
tbill_1972=data_2013_gw(ind_reit,9);  %--used to demean reit returns
inf=data_2013_gw(ind_2013,13);
dspr=data_2013_gw(ind_2013,10);
dpvw=data_2013_gw(ind_2013,5);
mktvol=data_2013_gw(ind_2013,15);

%---load the industry returns from all samples
returns_2013=data_2013_gw(ind_2013,16:end-1);    %---already returns, no scaling needed, 
                                        %---leave off the last returns, reit                                       
returns_reit=data_2013_gw(ind_reit,end);  %---reit return data is available from 1972 onward  
N_ind=size(returns_2013,2);
T_ind=size(returns_2013,1);

%---load additional GW(2013) controls
epvw=data_2013_gw(ind_2013,6);
de=data_2013_gw(ind_2013,7);
bm=data_2013_gw(ind_2013,8);
tspr=data_2013_gw(ind_2013,11);
ntis=data_2013_gw(ind_2013,12);

lbls={'AGRIC','MINES','OIL','STONE','CNSTR','FOOD','SMOKE','TXTLS','APPRL','WOOD','CHAIR','PAPER','PRINT','CHEMS','PTRLM','RUBBR','LETHR','GLASS','METAL','MTLPR','MACHN','ELCTR','CARS','INSTR','MANUF','TRANS','PHONE','TV','UTILS','WHLSL','RTAIL','MONEY','SRVC','RLEST'};
lbls_controls={'RM','INF','DSPR','MDY','MVOL'};

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%% Table 3: All Industries Forecasting RM, Specification 3 
%%%%%%%%%% Market Proxy: SP500 (2014)
%%%%%%%%%% Controls: INF,DSPR,MDY,NVOL (GW (2013))
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

RM=spret-tbill;
est2_mat=[];
T2_mat=[];
R2_mat=[];
%------for all industries, without real estate
cnt=0;
for t=481:T_ind;  %starting point for all industries, but REIT
    cnt=cnt+1;
    sstart=cnt;
    eend=t;
    yy=RM(sstart+1:eend); % forecasted variable: RM=e xcess returns
    
    for i=1:N_ind
        ind_x_ret=returns_2013(:,i)-tbill;
        xx=[ind_x_ret(sstart:eend-1) RM(sstart:eend-1) inf(sstart:eend-1) dspr(sstart:eend-1) dpvw(sstart:eend-1) mktvol(sstart:eend-1)];
        [estimates2,stderror2,R2v,R2vadj,v,F] = olsgmm(yy,[ones(length(xx),1) xx],12,1);  %--NW cochrane code
        est2_mat(i,cnt)=estimates2(2);
        T2_mat(i,cnt)=estimates2(2)./stderror2(2);
        R2_mat(i,cnt)=R2vadj;
    end
    
end

cnt=0;
reit_cnt=312;  %start of REIT data -1
for t=481:T_ind;
    reit_cnt=reit_cnt+1;
    cnt=cnt+1;
    if (t-reit_cnt)>=481
        sstart=cnt;
        eend=t;
    else
        sstart=313;  %beginning of the REIT sample
        eend=t;
    end
    
    yy=RM(sstart+1:eend); % forecasted variable: RM=e xcess returns
    
    ind_x_ret=data_2013_gw(sstart:eend-1,end)-tbill(sstart:eend-1);  %excess reit returns
    xx=[ind_x_ret RM(sstart:eend-1) inf(sstart:eend-1) dspr(sstart:eend-1) dpvw(sstart:eend-1) mktvol(sstart:eend-1)];
    [estimates2,stderror2,R2v,R2vadj,v,F] = olsgmm(yy,[ones(length(xx),1) xx],12,1);  %--NW cochrane code
    est2_mat(N_ind+1,cnt)=estimates2(2);    %last industry is RLEST
    T2_mat(N_ind+1,cnt)=estimates2(2)./stderror2(2);    %last industry is RLEST
    R2_mat(N_ind+1,cnt)=R2vadj;             %last industry is RLEST
        
end

cnt=0;
for t=481:T_ind;  %starting point for all industries, but REIT
    cnt=cnt+1;
    Sign_10(cnt,1)=sum(abs(T2_mat(:,cnt))>norminv(0.95,0,1));
    Sign_5(cnt,1)=sum(abs(T2_mat(:,cnt))>norminv(0.975,0,1));
end

Ind_Sign_10=sum(abs(T2_mat(:,:)')>norminv(0.95,0,1));

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Figures 1-3: Coefficients and Tstats, 14 Industries in HTV (2007)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
industries_to_display1=[34 2 4 9 13 ];
industries_to_display2=[15 17 19 26 28];
industries_to_display3=[29 31 32 33];

date_to_plot=datenum([year_2013(481:end) month_2013(481:end) 30.*ones(size(year_2013(481:end)))]); %-to convert to dates, for plotting
figure(1);clf;

subplot(2,1,1);
plot(date_to_plot,est2_mat([industries_to_display1],:)');
hold on
plot(date_to_plot,zeros(size(date_to_plot)),':');
datetick('x','yyyy')
title('Figure 1: Rolling \lambda_{i} Estimates for RLEST(blue), MINES(green), STONE(red), APPRL(cyan), PRINT(magenta)')
axis([min(date_to_plot) max(date_to_plot) -0.15 0.3])

subplot(2,1,2);
plot(date_to_plot,T2_mat([industries_to_display1],:)');
hold on
plot(date_to_plot,zeros(size(date_to_plot)),':');
plot(date_to_plot,-1.645.*ones(size(date_to_plot)),':');
plot(date_to_plot,1.645.*ones(size(date_to_plot)),':');
datetick('x','yyyy')
title('t(NW) statistics for RLEST(blue), MINES(green), STONE(red), APPRL(cyan), PRINT(magenta)')
axis([min(date_to_plot) max(date_to_plot) -4 4])

figure(2);clf

subplot(2,1,1);
plot(date_to_plot,est2_mat([industries_to_display2],:)');
hold on
plot(date_to_plot,zeros(size(date_to_plot)),':');
datetick('x','yyyy')
title('Figure 2: Rolling \lambda_{i} Estimates for PTRLM(blue), LETHR(green), METAL(red), TRANS(cyan), TV(magenta)')
axis([min(date_to_plot) max(date_to_plot) -0.15 0.3])

subplot(2,1,2);
plot(date_to_plot,T2_mat([industries_to_display2],:)');
hold on
plot(date_to_plot,zeros(size(date_to_plot)),':');
plot(date_to_plot,-1.645.*ones(size(date_to_plot)),':');
plot(date_to_plot,1.645.*ones(size(date_to_plot)),':');
datetick('x','yyyy')
title('t(NW) statistics for PTRLM(blue), LETHR(green), METAL(red), TRANS(cyan), TV(magenta)')
axis([min(date_to_plot) max(date_to_plot) -4 4])

figure(3);clf

subplot(2,1,1);
plot(date_to_plot,est2_mat([industries_to_display3],:)');
hold on
plot(date_to_plot,zeros(size(date_to_plot)),':');
datetick('x','yyyy')
title('Figure 3: Rolling \lambda_{i} Estimates for UTILS(blue), RTAIL(green), MONEY(red), SRVC(cyan)')
axis([min(date_to_plot) max(date_to_plot) -0.15 0.3])

subplot(2,1,2);
plot(date_to_plot,T2_mat([industries_to_display3],:)');
hold on
plot(date_to_plot,zeros(size(date_to_plot)),':');
plot(date_to_plot,-1.645.*ones(size(date_to_plot)),':');
plot(date_to_plot,1.645.*ones(size(date_to_plot)),':');
datetick('x','yyyy')
title('t(NW) statistics for UTILS(blue), RTAIL(green), MONEY(red), SRVC(cyen)')
axis([min(date_to_plot) max(date_to_plot) -4 4])


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Figure 4: Number of Significant Industries on a Rolling Basis
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
figure(4);clf;

plot(date_to_plot,Sign_10);
hold on
plot(date_to_plot,3.4.*ones(size(date_to_plot)),':');
datetick('x','yyyy')
title('Figure 4: Number of Significant Industries (Rolling Regressions)')
axis([min(date_to_plot) max(date_to_plot) 0 15])
xlabel('Year')
ylabel('Number of Significant Industries at the 10% Level')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Figure 5: Number of Significant Industries on a Rolling Basis
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
figure(5);clf;
bar([Ind_Sign_10(end) Ind_Sign_10(1:end-1)]);  %--put RLEST first, as in HTV(2007)
set(gca,'XTick',[1 3 5 10 14 16 18 20 27 29 30 32 33 34])
set(gca,'XTickLabel',{'RLEST', 'MINES','STONE','APPRL','PRINT','PTRLM','LETHR','METAL','TRANS','TV','UTILS','RTAIL','MONEY','SRVC'})
xticklabel_rotate
hold on
title('Figure 5: Number of Periods with Significant t(NW) (Rolling Regressions)')
xlabel('Industry')
ylabel('Months Significant (out of 336)')



