clear;
clc;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% To run this code:
% 1. Data in: us_data_variables_used.xls
% 2. Programs: olsgmm.m
% Code output: Output_2002.xls
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%---load data up to 2002
[data_2013_gw]=xlsread('us_data_1946_2013_goyal_french_wrds',1,'a2:aw817');  

year_2013=data_2013_gw(:,1);
month_2013=data_2013_gw(:,2);

%---make sure sample is 1946.01 to 2013.12 
ind_2013=find(year_2013>=1946 & year_2013<2014);
%---reit sample is 1972.01 to 2013.12 
ind_reit=find(year_2013>=1972 & year_2013<2014);

%---load market returns, various proxies
vwret=data_2013_gw(ind_2013,3); %vwretd downloaded in 2014
spret=data_2013_gw(ind_2013,4); %sp500 return downloaded in 2014

%---load GW(2013) controls
tbill=data_2013_gw(ind_2013,9);
tbill_1972=data_2013_gw(ind_reit,9);  %--used to demean reit returns
inf=data_2013_gw(ind_2013,13);
dspr=data_2013_gw(ind_2013,10);
dpvw=data_2013_gw(ind_2013,5);
mktvol=data_2013_gw(ind_2013,15);

%---load the industry returns from all samples
returns_2013=data_2013_gw(ind_2013,16:end-1);    %---already returns, no scaling needed, 
                                        %---leave off the last returns, reit                                       
returns_reit=data_2013_gw(ind_reit,end);  %---reit return data is available from 1972 onward  
N_ind=size(returns_2013,2);


%---load additional GW(2013) controls
epvw=data_2013_gw(ind_2013,6);
de=data_2013_gw(ind_2013,7);
bm=data_2013_gw(ind_2013,8);
tspr=data_2013_gw(ind_2013,11);
ntis=data_2013_gw(ind_2013,12);

lbls={'RLEST','AGRIC','MINES','OIL','STONE','CNSTR','FOOD','SMOKE','TXTLS','APPRL','WOOD','CHAIR','PAPER','PRINT','CHEMS','PTRLM','RUBBR','LETHR','GLASS','METAL','MTLPR','MACHN','ELCTR','CARS','INSTR','MANUF','TRANS','PHONE','TV','UTILS','WHLSL','RTAIL','MONEY','SRVC'};
lbls_controls={'RM','INF','DSPR','MDY','MVOL'};

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%% Table 3: All Industries Forecasting RM, Specification 3 
%%%%%%%%%% Market Proxy: SP500 (2014)
%%%%%%%%%% Controls: INF,DSPR,MDY,NVOL (GW (2013))
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

RM=spret-tbill;
yy=RM(2:end) % forecasted variable: RM=e xcess returns

est2_mat=[];
T2_mat=[];
R2_mat=[];
%------for all industries, without real estate
for i=1:N_ind
    
    ind_x_ret=returns_2013(:,i)-tbill;
    xx=[ind_x_ret(1:end-1) RM(1:end-1) inf(1:end-1) dspr(1:end-1) dpvw(1:end-1) mktvol(1:end-1)];    
    [estimates2,stderror2,R2v,R2vadj,v,F] = olsgmm(yy,[ones(length(xx),1) xx],12,1);  %--NW cochrane code
    est2_mat(i,1)=estimates2(2);
    T2_mat(i,1)=estimates2(2)./stderror2(2);
    R2_mat(i,1)=R2vadj;
end

%---for real estate, smaller sample
yy=RM(ind_reit(2):ind_reit(end))-tbill(ind_reit(2):ind_reit(end)); %excess returns
xx=[returns_reit(1:end-1) RM(ind_reit(1):ind_reit(end-1)) inf(ind_reit(1):ind_reit(end-1)) dspr(ind_reit(1):ind_reit(end-1)) dpvw(ind_reit(1):ind_reit(end-1)) mktvol(ind_reit(1):ind_reit(end-1))];    
[estimates2,stderror2,R2v,R2vadj,v,F] = olsgmm(yy,[ones(length(xx),1) xx],12,1);  %--NW cochrane code
est2_mat=[estimates2(2);est2_mat];
T2_mat=[estimates2(2)./stderror2(2);T2_mat];
R2_mat=[R2vadj;R2_mat];

%---significant industries at 10 and 5 percent
Sign_10=sum(abs(T2_mat)>norminv(0.95,0,1));
Sign_5=sum(abs(T2_mat)>norminv(0.975,0,1));

%---display the results of coefficient in front of industry returns and
%T-stat
[[1:34]' est2_mat T2_mat R2_mat]
[Sign_10 Sign_5 ]

%---write results to excel spreadsheet
xlswrite('Output_2013.xls',{'Market Proxy:','SP500(2014)'},1,'A1')
xlswrite('Output_2013.xls',{'Industries:','French, New'},1,'A2')
xlswrite('Output_2013.xls',{'Controls:','GW(2013)'},1,'A3')
xlswrite('Output_2013.xls',{'Sample:','46-13'},1,'A4')

xlswrite('Output_2013.xls',{'Industry','Ind(-1)','NW(12)','R2'},1,'A5')
xlswrite('Output_2013.xls',lbls',1,'A7')
xlswrite('Output_2013.xls',est2_mat,1,'B7')
xlswrite('Output_2013.xls',T2_mat,1,'C7')
xlswrite('Output_2013.xls',R2_mat,1,'D7')

xlswrite('Output_2013.xls',{'# 10pct','# 5pct'}',1,'A42')
xlswrite('Output_2013.xls',[Sign_10; Sign_5],1,'B42')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%% Table 3: All Industries Forecasting RM, Specification 3 
%%%%%%%%%% Market Proxy: SP500 (2014)
%%%%%%%%%% Controls: GW(2005): INF, DSPR, MDY, MVOL, TSPR, BM, NTIS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

RM=spret-tbill;
yy=RM(2:end) % forecasted variable: RM=e xcess returns

est2_mat=[];
T2_mat=[];
R2_mat=[];
%------for all industries, without real estate
for i=1:N_ind
    
    ind_x_ret=returns_2013(:,i)-tbill;
    xx=[ind_x_ret(1:end-1) RM(1:end-1) inf(1:end-1) dspr(1:end-1) dpvw(1:end-1) mktvol(1:end-1) tspr(1:end-1) bm(1:end-1) ntis(1:end-1)];    
    [estimates2,stderror2,R2v,R2vadj,v,F] = olsgmm(yy,[ones(length(xx),1) xx],12,1);  %--NW cochrane code
    est2_mat(i,1)=estimates2(2);
    T2_mat(i,1)=estimates2(2)./stderror2(2);
    R2_mat(i,1)=R2vadj;
end

%---for real estate, smaller sample
yy=RM(ind_reit(2):ind_reit(end))-tbill(ind_reit(2):ind_reit(end)); %excess returns
xx=[returns_reit(1:end-1) RM(ind_reit(1):ind_reit(end-1)) inf(ind_reit(1):ind_reit(end-1)) dspr(ind_reit(1):ind_reit(end-1)) dpvw(ind_reit(1):ind_reit(end-1)) ...
    mktvol(ind_reit(1):ind_reit(end-1)) tspr(ind_reit(1):ind_reit(end-1)) bm(ind_reit(1):ind_reit(end-1)) ntis(ind_reit(1):ind_reit(end-1))];    
[estimates2,stderror2,R2v,R2vadj,v,F] = olsgmm(yy,[ones(length(xx),1) xx],12,1);  %--NW cochrane code
est2_mat=[estimates2(2);est2_mat];
T2_mat=[estimates2(2)./stderror2(2);T2_mat];
R2_mat=[R2vadj;R2_mat];

%---significant industries at 10 and 5 percent
Sign_10=sum(abs(T2_mat)>norminv(0.95,0,1));
Sign_5=sum(abs(T2_mat)>norminv(0.975,0,1));

%---display the results of coefficient in front of industry returns and
%T-stat
[[1:34]' est2_mat T2_mat R2_mat]
[Sign_10 Sign_5 ]

%---write results to excel spreadsheet
xlswrite('Output_2013.xls',{'Market Proxy:','SP500(2014)'},1,'F1')
xlswrite('Output_2013.xls',{'Industries:','French, New'},1,'F2')
xlswrite('Output_2013.xls',{'Controls:','GW(2013) Extended'},1,'F3')
xlswrite('Output_2013.xls',{'Sample:','46-13'},1,'F4')

xlswrite('Output_2013.xls',{'Industry','Ind(-1)','NW(12)','R2'},1,'F5')
xlswrite('Output_2013.xls',lbls',1,'F7')
xlswrite('Output_2013.xls',est2_mat,1,'G7')
xlswrite('Output_2013.xls',T2_mat,1,'H7')
xlswrite('Output_2013.xls',R2_mat,1,'I7')

xlswrite('Output_2013.xls',{'# 10pct','# 5pct'}',1,'F42')
xlswrite('Output_2013.xls',[Sign_10; Sign_5],1,'G42')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%% Table 3: All Industries Forecasting RM, Specification 3 
%%%%%%%%%% Market Proxy: VWRETD (2014)
%%%%%%%%%% Controls: INF,DSPR,MDY,NVOL (GW (2013))
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

RM=vwret-tbill;
yy=RM(2:end) % forecasted variable: RM=e xcess returns

est2_mat=[];
T2_mat=[];
R2_mat=[];
%------for all industries, without real estate
for i=1:N_ind
    
    ind_x_ret=returns_2013(:,i)-tbill;
    xx=[ind_x_ret(1:end-1) RM(1:end-1) inf(1:end-1) dspr(1:end-1) dpvw(1:end-1) mktvol(1:end-1)];    
    [estimates2,stderror2,R2v,R2vadj,v,F] = olsgmm(yy,[ones(length(xx),1) xx],12,1);  %--NW cochrane code
    est2_mat(i,1)=estimates2(2);
    T2_mat(i,1)=estimates2(2)./stderror2(2);
    R2_mat(i,1)=R2vadj;
end

%---for real estate, smaller sample
yy=RM(ind_reit(2):ind_reit(end))-tbill(ind_reit(2):ind_reit(end)); %excess returns
xx=[returns_reit(1:end-1) RM(ind_reit(1):ind_reit(end-1)) inf(ind_reit(1):ind_reit(end-1)) dspr(ind_reit(1):ind_reit(end-1)) dpvw(ind_reit(1):ind_reit(end-1)) mktvol(ind_reit(1):ind_reit(end-1))];    
[estimates2,stderror2,R2v,R2vadj,v,F] = olsgmm(yy,[ones(length(xx),1) xx],12,1);  %--NW cochrane code
est2_mat=[estimates2(2);est2_mat];
T2_mat=[estimates2(2)./stderror2(2);T2_mat];
R2_mat=[R2vadj;R2_mat];

%---significant industries at 10 and 5 percent
Sign_10=sum(abs(T2_mat)>norminv(0.95,0,1));
Sign_5=sum(abs(T2_mat)>norminv(0.975,0,1));

%---display the results of coefficient in front of industry returns and
%T-stat
[[1:34]' est2_mat T2_mat R2_mat]
[Sign_10 Sign_5 ]

%---write results to excel spreadsheet
xlswrite('Output_2013.xls',{'Market Proxy:','VWRETD(2014)'},1,'K1')
xlswrite('Output_2013.xls',{'Industries:','French, New'},1,'K2')
xlswrite('Output_2013.xls',{'Controls:','GW(2013)'},1,'K3')
xlswrite('Output_2013.xls',{'Sample:','46-13'},1,'K4')

xlswrite('Output_2013.xls',{'Industry','Ind(-1)','NW(12)','R2'},1,'K5')
xlswrite('Output_2013.xls',lbls',1,'K7')
xlswrite('Output_2013.xls',est2_mat,1,'L7')
xlswrite('Output_2013.xls',T2_mat,1,'M7')
xlswrite('Output_2013.xls',R2_mat,1,'N7')

xlswrite('Output_2013.xls',{'# 10pct','# 5pct'}',1,'K42')
xlswrite('Output_2013.xls',[Sign_10; Sign_5],1,'L42')

