clear;
clc;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% To run this code:
% 1. Data in: us_data_variables_used.xls
% 2. Programs: olsgmm.m
% Code output: Output_2002.xls
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%---load data up to 2002
[data_pp]=xlsread('us_data_variables_used',1,'a2:as685');  
[data_gw]=xlsread('us_data_variables_used',2,'a2:z685');  

year_pp=data_pp(:,1);
month_pp=data_pp(:,2);

%---make sure sample is 1946.01 to 2002.12 
ind_pp=find(year_pp>=1946 & year_pp<2003);
%---reit sample is 1972.01 to 2002.12 
ind_reit=find(year_pp>=1972 & year_pp<2003);

%---load market returns, various proxies
vwret=data_pp(ind_pp,3); %vwretd downloaded in 2004
spret_gw=data_pp(ind_pp,4); %sp500 return from GW(2005)
vwret_2014=data_pp(ind_pp,5);%vwretd downloaded Sept, 2014 

%---load controls
%---from 2004
tbill=data_pp(ind_pp,6);
tbill_1972=data_pp(ind_reit,6);  %--used to demean reit returns
inf=data_pp(ind_pp,7);
dspr=data_pp(ind_pp,8);
dpvw=data_pp(ind_pp,9);
mktvol=data_pp(ind_pp,10);

%---load the industry returns from all samples
returns_pp=data_pp(ind_pp,11:end-1);    %---already returns, no scaling needed, 
                                        %---leave off the last returns, reit                                       
returns_reit=data_pp(ind_reit,end);  %---reit return data is available from 1972 onward  
N_ind=size(returns_pp,2);

%---load GW(2005) controls
tbill_gw=data_gw(ind_pp,11);
tbill_gw_1972=data_gw(ind_reit,11);  %--used to demean reit returns
inf_gw=data_gw(ind_pp,20);
dspr_gw=data_gw(ind_pp,14);
dpvw_gw=data_gw(ind_pp,5);
mktvol_gw=data_gw(ind_pp,25);

epvw_gw=data_gw(ind_pp,7);
de_gw=data_gw(ind_pp,8);
bm_gw=data_gw(ind_pp,9);
tspr_gw=data_gw(ind_pp,16);
ntis_gw=data_gw(ind_pp,18);

lbls={'RLEST','AGRIC','MINES','OIL','STONE','CNSTR','FOOD','SMOKE','TXTLS','APPRL','WOOD','CHAIR','PAPER','PRINT','CHEMS','PTRLM','RUBBR','LETHR','GLASS','METAL','MTLPR','MACHN','ELCTR','CARS','INSTR','MANUF','TRANS','PHONE','TV','UTILS','WHLSL','RTAIL','MONEY','SRVC'};

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%% Table 3: All Industries Forecasting RM, Specification 3 
%%%%%%%%%% Market Proxy: VWRETD (2005)
%%%%%%%%%% Controls: INF,DSPR,MDY,NVOL (2005)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

RM=vwret-tbill;
yy=RM(2:end) % forecasted variable: RM=e xcess returns

est2_mat=[];
T2_mat=[];
R2_mat=[];
%------for all industries, without real estate
for i=1:N_ind
    
    ind_x_ret=returns_pp(:,i)-tbill;
    xx=[ind_x_ret(1:end-1) RM(1:end-1) inf(1:end-1) dspr(1:end-1) dpvw(1:end-1) mktvol(1:end-1)];    
    [estimates2,stderror2,R2v,R2vadj,v,F] = olsgmm(yy,[ones(length(xx),1) xx],12,1);  %--NW cochrane code
    est2_mat(i,1)=estimates2(2);
    T2_mat(i,1)=estimates2(2)./stderror2(2);
    R2_mat(i,1)=R2vadj;
end

%---for real estate, smaller sample
yy=RM(ind_reit(2):ind_reit(end))-tbill(ind_reit(2):ind_reit(end)); %excess returns
xx=[returns_reit(1:end-1) RM(ind_reit(1):ind_reit(end-1)) inf(ind_reit(1):ind_reit(end-1)) dspr(ind_reit(1):ind_reit(end-1)) dpvw(ind_reit(1):ind_reit(end-1)) mktvol(ind_reit(1):ind_reit(end-1))];    
[estimates2,stderror2,R2v,R2vadj,v,F] = olsgmm(yy,[ones(length(xx),1) xx],12,1);  %--NW cochrane code
est2_mat=[estimates2(2);est2_mat];
T2_mat=[estimates2(2)./stderror2(2);T2_mat];
R2_mat=[R2vadj;R2_mat];

%---significant industries at 10 and 5 percent
Sign_10=sum(abs(T2_mat)>norminv(0.95,0,1));
Sign_5=sum(abs(T2_mat)>norminv(0.975,0,1));

%---display the results of coefficient in front of industry returns and
%T-stat
[[1:34]' est2_mat T2_mat R2_mat]
[Sign_10 Sign_5 ]

%---write results to excel spreadsheet
xlswrite('Output_2002.xls',{'Market Proxy:','VWRETD(2005)'},1,'A1')
xlswrite('Output_2002.xls',{'Industries:','French, Old'},1,'A2')
xlswrite('Output_2002.xls',{'Controls:','2005'},1,'A3')
xlswrite('Output_2002.xls',{'Sample:','46-02'},1,'A4')

xlswrite('Output_2002.xls',{'Industry','Ind(-1)','t(NW)','R2'},1,'A5')
xlswrite('Output_2002.xls',lbls',1,'A7')
xlswrite('Output_2002.xls',est2_mat,1,'B7')
xlswrite('Output_2002.xls',T2_mat,1,'C7')
xlswrite('Output_2002.xls',R2_mat,1,'D7')

xlswrite('Output_2002.xls',{'# 10pct','# 5pct'}',1,'A42')
xlswrite('Output_2002.xls',[Sign_10; Sign_5],1,'B42')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%% Table 3: All Industries Forecasting RM, Specification 3 
%%%%%%%%%% Market Proxy: SP500 (GW, 2005)
%%%%%%%%%% Controls: INF,DSPR,MDY,NVOL (2005)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

RM=spret_gw-tbill;
yy=RM(2:end) % forecasted variable: RM=excess returns

est2_mat=[];
T2_mat=[];
R2_mat=[];
%------for all industries, without real estate
for i=1:N_ind
    
    ind_x_ret=returns_pp(:,i)-tbill;
    xx=[ind_x_ret(1:end-1) RM(1:end-1) inf(1:end-1) dspr(1:end-1) dpvw(1:end-1) mktvol(1:end-1)];    
    [estimates2,stderror2,R2v,R2vadj,v,F] = olsgmm(yy,[ones(length(xx),1) xx],12,1);  %--NW cochrane code
    est2_mat(i,1)=estimates2(2);
    T2_mat(i,1)=estimates2(2)./stderror2(2);
    R2_mat(i,1)=R2vadj;
end

%---for real estate, smaller sample
yy=RM(ind_reit(2):ind_reit(end))-tbill(ind_reit(2):ind_reit(end)); %excess returns
xx=[returns_reit(1:end-1) RM(ind_reit(1):ind_reit(end-1)) inf(ind_reit(1):ind_reit(end-1)) dspr(ind_reit(1):ind_reit(end-1)) dpvw(ind_reit(1):ind_reit(end-1)) mktvol(ind_reit(1):ind_reit(end-1))];    
[estimates2,stderror2,R2v,R2vadj,v,F] = olsgmm(yy,[ones(length(xx),1) xx],12,1);  %--NW cochrane code
est2_mat=[estimates2(2);est2_mat];
T2_mat=[estimates2(2)./stderror2(2);T2_mat];
R2_mat=[R2vadj;R2_mat];

%---significant industries at 10 and 5 percent
Sign_10=sum(abs(T2_mat)>norminv(0.95,0,1));
Sign_5=sum(abs(T2_mat)>norminv(0.975,0,1));

%---display the results of coefficient in front of industry returns and
%T-stat
[[1:34]' est2_mat T2_mat R2_mat]
[Sign_10 Sign_5 ]

%---write results to excel spreadsheet
xlswrite('Output_2002.xls',{'Market Proxy:','SP500(GW, 2005)'},1,'F1')
xlswrite('Output_2002.xls',{'Industries:','French, Old'},1,'F2')
xlswrite('Output_2002.xls',{'Controls:','2005'},1,'F3')
xlswrite('Output_2002.xls',{'Sample:','46-02'},1,'F4')

xlswrite('Output_2002.xls',{'Industry','Ind(-1)','t(NW)','R2'},1,'F5')
xlswrite('Output_2002.xls',lbls',1,'F7')
xlswrite('Output_2002.xls',est2_mat,1,'G7')
xlswrite('Output_2002.xls',T2_mat,1,'H7')
xlswrite('Output_2002.xls',R2_mat,1,'I7')

xlswrite('Output_2002.xls',{'# 10pct','# 5pct'}',1,'F42')
xlswrite('Output_2002.xls',[Sign_10; Sign_5],1,'G42')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%% Table 3: All Industries Forecasting RM, Specification 3 
%%%%%%%%%% Market Proxy: SP500 (GW, 2005)
%%%%%%%%%% Controls: GW(2005): INF, DSPR, MDY, MVOL
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

RM=spret_gw-tbill;
yy=RM(2:end) % forecasted variable: RM=excess returns

est2_mat=[];
T2_mat=[];
R2_mat=[];
%------for all industries, without real estate
for i=1:N_ind
    
    ind_x_ret=returns_pp(:,i)-tbill;
    xx=[ind_x_ret(1:end-1) RM(1:end-1) inf_gw(1:end-1) dspr_gw(1:end-1) dpvw_gw(1:end-1) mktvol_gw(1:end-1)];    
    [estimates2,stderror2,R2v,R2vadj,v,F] = olsgmm(yy,[ones(length(xx),1) xx],12,1);  %--NW cochrane code
    est2_mat(i,1)=estimates2(2);
    T2_mat(i,1)=estimates2(2)./stderror2(2);
    R2_mat(i,1)=R2vadj;
end

%---for real estate, smaller sample
yy=RM(ind_reit(2):ind_reit(end))-tbill(ind_reit(2):ind_reit(end)); %excess returns
xx=[returns_reit(1:end-1) RM(ind_reit(1):ind_reit(end-1)) inf_gw(ind_reit(1):ind_reit(end-1)) dspr_gw(ind_reit(1):ind_reit(end-1)) dpvw_gw(ind_reit(1):ind_reit(end-1)) mktvol_gw(ind_reit(1):ind_reit(end-1))];    
[estimates2,stderror2,R2v,R2vadj,v,F] = olsgmm(yy,[ones(length(xx),1) xx],12,1);  %--NW cochrane code
est2_mat=[estimates2(2);est2_mat];
T2_mat=[estimates2(2)./stderror2(2);T2_mat];
R2_mat=[R2vadj;R2_mat];

%---significant industries at 10 and 5 percent
Sign_10=sum(abs(T2_mat)>norminv(0.95,0,1));
Sign_5=sum(abs(T2_mat)>norminv(0.975,0,1));

%---display the results of coefficient in front of industry returns and
%T-stat
[[1:34]' est2_mat T2_mat R2_mat]
[Sign_10 Sign_5 ]

%---write results to excel spreadsheet
xlswrite('Output_2002.xls',{'Market Proxy:','SP500(GW, 2005)'},1,'K1')
xlswrite('Output_2002.xls',{'Industries:','French, Old'},1,'K2')
xlswrite('Output_2002.xls',{'Controls:','GW(2005)'},1,'K3')
xlswrite('Output_2002.xls',{'Sample:','46-02'},1,'K4')

xlswrite('Output_2002.xls',{'Industry','Ind(-1)','t(NW)','R2'},1,'K5')
xlswrite('Output_2002.xls',lbls',1,'K7')
xlswrite('Output_2002.xls',est2_mat,1,'L7')
xlswrite('Output_2002.xls',T2_mat,1,'M7')
xlswrite('Output_2002.xls',R2_mat,1,'N7')

xlswrite('Output_2002.xls',{'# 10pct','# 5pct'}',1,'K42')
xlswrite('Output_2002.xls',[Sign_10; Sign_5],1,'L42')


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%% Table 3: All Industries Forecasting RM, Specification 3 
%%%%%%%%%% Market Proxy: SP500 (GW, 2005)
%%%%%%%%%% Controls: GW(2005): INF, DSPR, MDY, MVOL, TSPR, BM, NTIS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

RM=spret_gw-tbill;
yy=RM(2:end) % forecasted variable: RM=excess returns

est2_mat=[];
T2_mat=[];
R2_mat=[];
%------for all industries, without real estate
for i=1:N_ind
    
    ind_x_ret=returns_pp(:,i)-tbill;
    xx=[ind_x_ret(1:end-1) RM(1:end-1) inf_gw(1:end-1) dspr_gw(1:end-1) dpvw_gw(1:end-1) mktvol_gw(1:end-1) tspr_gw(1:end-1) bm_gw(1:end-1) ntis_gw(1:end-1)];    
    [estimates2,stderror2,R2v,R2vadj,v,F] = olsgmm(yy,[ones(length(xx),1) xx],12,1);  %--NW cochrane code
    est2_mat(i,1)=estimates2(2);
    T2_mat(i,1)=estimates2(2)./stderror2(2);
    R2_mat(i,1)=R2vadj;
end

%---for real estate, smaller sample
yy=RM(ind_reit(2):ind_reit(end))-tbill(ind_reit(2):ind_reit(end)); %excess returns
xx=[returns_reit(1:end-1) RM(ind_reit(1):ind_reit(end-1)) inf_gw(ind_reit(1):ind_reit(end-1)) dspr_gw(ind_reit(1):ind_reit(end-1)) dpvw_gw(ind_reit(1):ind_reit(end-1)) ...
    mktvol_gw(ind_reit(1):ind_reit(end-1)) tspr_gw(ind_reit(1):ind_reit(end-1)) bm_gw(ind_reit(1):ind_reit(end-1)) ntis_gw(ind_reit(1):ind_reit(end-1))];    
[estimates2,stderror2,R2v,R2vadj,v,F] = olsgmm(yy,[ones(length(xx),1) xx],12,1);  %--NW cochrane code
est2_mat=[estimates2(2);est2_mat];
T2_mat=[estimates2(2)./stderror2(2);T2_mat];
R2_mat=[R2vadj;R2_mat];

%---significant industries at 10 and 5 percent
Sign_10=sum(abs(T2_mat)>norminv(0.95,0,1));
Sign_5=sum(abs(T2_mat)>norminv(0.975,0,1));

%---display the results of coefficient in front of industry returns and
%T-stat
[[1:34]' est2_mat T2_mat R2_mat]
[Sign_10 Sign_5 ]

%---write results to excel spreadsheet
xlswrite('Output_2002.xls',{'Market Proxy:','SP500(GW, 2005)'},1,'P1')
xlswrite('Output_2002.xls',{'Industries:','French, Old'},1,'P2')
xlswrite('Output_2002.xls',{'Controls:','GW (2005) Extended'},1,'P3')
xlswrite('Output_2002.xls',{'Sample:','46-02'},1,'P4')

xlswrite('Output_2002.xls',{'Industry','Ind(-1)','t(NW)','R2'},1,'P5')
xlswrite('Output_2002.xls',lbls',1,'P7')
xlswrite('Output_2002.xls',est2_mat,1,'Q7')
xlswrite('Output_2002.xls',T2_mat,1,'R7')
xlswrite('Output_2002.xls',R2_mat,1,'S7')

xlswrite('Output_2002.xls',{'# 10pct','# 5pct'}',1,'P42')
xlswrite('Output_2002.xls',[Sign_10; Sign_5],1,'Q42')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%% Table 3: All Industries Forecasting RM, Specification 3 
%%%%%%%%%% Market Proxy: VWRET (Downloaded: 2014)
%%%%%%%%%% Controls: INF,DSPR,MDY,NVOL (2005)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

RM=vwret_2014-tbill;
yy=RM(2:end) % forecasted variable: RM=excess returns

est2_mat=[];
T2_mat=[];
R2_mat=[];
%------for all industries, without real estate
for i=1:N_ind
    
    ind_x_ret=returns_pp(:,i)-tbill;
    xx=[ind_x_ret(1:end-1) RM(1:end-1) inf(1:end-1) dspr(1:end-1) dpvw(1:end-1) mktvol(1:end-1)];    
    [estimates2,stderror2,R2v,R2vadj,v,F] = olsgmm(yy,[ones(length(xx),1) xx],12,1);  %--NW cochrane code
    est2_mat(i,1)=estimates2(2);
    T2_mat(i,1)=estimates2(2)./stderror2(2);
    R2_mat(i,1)=R2vadj;
end

%---for real estate, smaller sample
yy=RM(ind_reit(2):ind_reit(end))-tbill(ind_reit(2):ind_reit(end)); %excess returns
xx=[returns_reit(1:end-1) RM(ind_reit(1):ind_reit(end-1)) inf(ind_reit(1):ind_reit(end-1)) dspr(ind_reit(1):ind_reit(end-1)) dpvw(ind_reit(1):ind_reit(end-1)) mktvol(ind_reit(1):ind_reit(end-1))];    
[estimates2,stderror2,R2v,R2vadj,v,F] = olsgmm(yy,[ones(length(xx),1) xx],12,1);  %--NW cochrane code
est2_mat=[estimates2(2);est2_mat];
T2_mat=[estimates2(2)./stderror2(2);T2_mat];
R2_mat=[R2vadj;R2_mat];

%---significant industries at 10 and 5 percent
Sign_10=sum(abs(T2_mat)>norminv(0.95,0,1));
Sign_5=sum(abs(T2_mat)>norminv(0.975,0,1));

%---display the results of coefficient in front of industry returns and
%T-stat
[[1:34]' est2_mat T2_mat R2_mat]
[Sign_10 Sign_5 ]

%---write results to excel spreadsheet
xlswrite('Output_2002.xls',{'Market Proxy:','VWRETD(2014)'},1,'U1')
xlswrite('Output_2002.xls',{'Industries:','French, Old'},1,'U2') 
xlswrite('Output_2002.xls',{'Controls:','2005'},1,'U3')
xlswrite('Output_2002.xls',{'Sample:','46-02'},1,'U4')

xlswrite('Output_2002.xls',{'Industry','Ind(-1)','t(NW)','R2'},1,'U5')
xlswrite('Output_2002.xls',lbls',1,'U7')
xlswrite('Output_2002.xls',est2_mat,1,'V7')
xlswrite('Output_2002.xls',T2_mat,1,'W7')
xlswrite('Output_2002.xls',R2_mat,1,'X7')

xlswrite('Output_2002.xls',{'# 10pct','# 5pct'}',1,'U42')
xlswrite('Output_2002.xls',[Sign_10; Sign_5],1,'V42')

